pychemia.code.vasp.task package
===============================

.. automodule:: pychemia.code.vasp.task
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

pychemia.code.vasp.task.convergence module
------------------------------------------

.. automodule:: pychemia.code.vasp.task.convergence
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.vasp.task.elastic module
--------------------------------------

.. automodule:: pychemia.code.vasp.task.elastic
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.vasp.task.polarization module
-------------------------------------------

.. automodule:: pychemia.code.vasp.task.polarization
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.vasp.task.relax module
------------------------------------

.. automodule:: pychemia.code.vasp.task.relax
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.vasp.task.static module
-------------------------------------

.. automodule:: pychemia.code.vasp.task.static
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.code.vasp.task.stregth module
--------------------------------------

.. automodule:: pychemia.code.vasp.task.stregth
    :members:
    :undoc-members:
    :show-inheritance:


